/*******************************************************************************
* Copyright (C) 2019 China Micro Semiconductor Limited Company. All Rights Reserved.
*
* This software is owned and published by:
* CMS LLC, No 2609-10, Taurus Plaza, TaoyuanRoad, NanshanDistrict, Shenzhen, China.
*
* BY DOWNLOADING, INSTALLING OR USING THIS SOFTWARE, YOU AGREE TO BE BOUND
* BY ALL THE TERMS AND CONDITIONS OF THIS AGREEMENT.
*
* This software contains source code for use with CMS
* components. This software is licensed by CMS to be adapted only
* for use in systems utilizing CMS components. CMS shall not be
* responsible for misuse or illegal use of this software for devices not
* supported herein. CMS is providing this software "AS IS" and will
* not be responsible for issues arising from incorrect user implementation
* of the software.
*
* This software may be replicated in part or whole for the licensed use,
* with the restriction that this Disclaimer and Copyright notice must be
* included with each copy of this software, whether used in part or whole,
* at all times.
*/

/****************************************************************************/
/** \file demo_lcd.c
**
**  
**
**	History:
**	
*****************************************************************************/
/****************************************************************************/
/*	include files
*****************************************************************************/
#include "demo_lcd.h"

/****************************************************************************/
/*	Local pre-processor symbols('#define')
****************************************************************************/

/****************************************************************************/
/*	Global variable definitions(declared in header file with 'extern')
****************************************************************************/


/****************************************************************************/
/*	Local type definitions('typedef')
****************************************************************************/

/****************************************************************************/
/*	Local variable  definitions('static')
****************************************************************************/


/****************************************************************************/
/*	Local function prototypes('static')
****************************************************************************/

/****************************************************************************/
/*	Function implementation - global ('extern') and local('static')
****************************************************************************/

/******************************************************************************
 ** \brief	 LCD_Config
 ** \param [in] 
 **            	
 ** \return  none
 ** \note  4位8字7段码时钟液晶显示屏  3.3V  1/3 Bias 1/4 Duty
 ******************************************************************************/
void LCD_Config(void)
{
	/*
	(1)设置LCD模块运行模式
	*/
	LCD_ConfigRunMode(LCD_DISPLAY_NORMAL);

	
	LCD_ConfigCOMMode( LCD_COMMODE_0, LCD_COMSEL_0, LCD_DUTY_4);		//1/4DUTY
	LCD_ConfigVLCD(LCD_VSEL_VLCD, 5, LCD_BIAS_3);						//VDD =5V, VLcv = 3.3V , 1/3bias

	LCD_ConfigClk(LCD_CLK_FSYS, LCD_CLKDIV_4096);
	LCD_ConfigResistance(LCD_FCMODE_0, LCD_R_60K, LCD_FCCTL_8);
	
	LCD_DriveCurrent(0x00);		//100uA
	/*
	(2)设置COM口
	*/
	GPIO_SET_MUX_MODE(P30CFG, GPIO_MUX_ANA);	//COM0
	GPIO_SET_MUX_MODE(P31CFG, GPIO_MUX_ANA);	//COM1	
	GPIO_SET_MUX_MODE(P32CFG, GPIO_MUX_ANA);	//COM2
	GPIO_SET_MUX_MODE(P33CFG, GPIO_MUX_ANA);	//COM3	
	
	LCDCOMEN = 0x0f;		//使能COM0~COM3
		
	/*
	(3)设置SEG口
	*/	
	GPIO_SET_MUX_MODE(P20CFG, GPIO_MUX_ANA);	//SEG8	-> 段码屏 SEG0
	GPIO_SET_MUX_MODE(P21CFG, GPIO_MUX_ANA);	//SEG9	-> 段码屏 SEG1
	GPIO_SET_MUX_MODE(P22CFG, GPIO_MUX_ANA);	//SEG10	-> 段码屏 SEG2	
	GPIO_SET_MUX_MODE(P23CFG, GPIO_MUX_ANA);	//SEG11	-> 段码屏 SEG3
	GPIO_SET_MUX_MODE(P24CFG, GPIO_MUX_ANA);	//SEG12	-> 段码屏 SEG4	
	GPIO_SET_MUX_MODE(P25CFG, GPIO_MUX_ANA);	//SEG13	-> 段码屏 SEG5	
	GPIO_SET_MUX_MODE(P26CFG, GPIO_MUX_ANA);	//SEG14	-> 段码屏 SEG6	
	GPIO_SET_MUX_MODE(P27CFG, GPIO_MUX_ANA);	//SEG15	-> 段码屏 SEG7	
	
	LCDSEGEN1 = 0xFF;	//使能SEG8~SEG15	
	
	/*
	(6)设置SEG口数据
	*/
	LCDSEG8 = 0x00;
	LCDSEG9 = 0x00;	
	LCDSEG10 = 0x00;	
	LCDSEG11 = 0x00;
	LCDSEG12 = 0x00;
	LCDSEG13 = 0x00;
	LCDSEG14 = 0x00;
	LCDSEG15 = 0x00;
	/*
	(7)开启LCD
	*/
	LCD_Start();
}

/******************************************************************************
 ** \brief	 LCD_Display
 ** \param [in] none
 ** \return  none
 ** \note   4位8字7段码时钟液晶显示屏: 显示1 2 3 4
 ******************************************************************************/
 void LCD_Display(void)
 {	 
		LCDSEG8 = 0x00;
		LCDSEG9 = 0x05;	
		LCDSEG10 = 0x05;	
		LCDSEG11 = 0x0B;
		LCDSEG12 = 0x01;
		LCDSEG13 = 0x0F;
		LCDSEG14 = 0x02;
		LCDSEG15 = 0x07;
 }



















