/*******************************************************************************
* Copyright (C) 2019 China Micro Semiconductor Limited Company. All Rights Reserved.
*
* This software is owned and published by:
* CMS LLC, No 2609-10, Taurus Plaza, TaoyuanRoad, NanshanDistrict, Shenzhen, China.
*
* BY DOWNLOADING, INSTALLING OR USING THIS SOFTWARE, YOU AGREE TO BE BOUND
* BY ALL THE TERMS AND CONDITIONS OF THIS AGREEMENT.
*
* This software contains source code for use with CMS
* components. This software is licensed by CMS to be adapted only
* for use in systems utilizing CMS components. CMS shall not be
* responsible for misuse or illegal use of this software for devices not
* supported herein. CMS is providing this software "AS IS" and will
* not be responsible for issues arising from incorrect user implementation
* of the software.
*
* This software may be replicated in part or whole for the licensed use,
* with the restriction that this Disclaimer and Copyright notice must be
* included with each copy of this software, whether used in part or whole,
* at all times.
*/

/****************************************************************************/
/** \file demo_timer.c
**
**  
**
**	History:
**	
*****************************************************************************/
/****************************************************************************/
/*	include files
*****************************************************************************/
#include "demo_timer.h"

/****************************************************************************/
/*	Local pre-processor symbols('#define')
****************************************************************************/

/****************************************************************************/
/*	Global variable definitions(declared in header file with 'extern')
****************************************************************************/

/****************************************************************************/
/*	Local type definitions('typedef')
****************************************************************************/

/****************************************************************************/
/*	Local variable  definitions('static')
****************************************************************************/

/****************************************************************************/
/*	Local function prototypes('static')
****************************************************************************/

/****************************************************************************/
/*	Function implementation - global ('extern') and local('static')
****************************************************************************/
/******************************************************************************
** \brief	 TMR2_Config
** \param [in] 
**            	
** \return  none
** \note  
******************************************************************************/
void TMR2_Config(void)
{
	/*
	(1)设置Timer运行时钟
	*/
	TMR2_ConfigTimerClk(TMR2_CLK_DIV_12);		/*Fsys = 24Mhz，Ftimer = 2Mhz, */
	/*
	(2)重载模式
	*/	
	TMR2_ConfigReLoadMode(TMR2_RELOAD_DISBALE);
	/*
	(3)设置数据寄存器
	*/	
	TMR2_ConfigDataRegister((65536 - 2000));		  
	/*
	(5)设置运行模式
	*/		 	
	TMR2_ConfigCompareMode(TMR2_CMP_MODE0);	
	TMR2_EnableCompare(TMR2_CC0);
	TMR2_EnableCompare(TMR2_CC1);	
	TMR2_EnableCompare(TMR2_CC2);
	TMR2_EnableCompare(TMR2_CC3);	
	
	TMR2_ConfigCompareValue(TMR2_CC0,(65536-100));
	TMR2_ConfigCompareValue(TMR2_CC1,(65536-500));	
	TMR2_ConfigCompareValue(TMR2_CC2,(65536-1000));	
	TMR2_ConfigCompareValue(TMR2_CC3,(65536-1500));	
	
	/*
	(6)开启中断
	*/
	TMR2_EnableOverflowInt();
	TMR2_EnableCompareInt(TMR2_CC0);
	TMR2_EnableCompareInt(TMR2_CC1);	
	TMR2_EnableCompareInt(TMR2_CC2);	
	TMR2_EnableCompareInt(TMR2_CC3);	
		
	TMR2_ConfigCompareIntMode(TMR2_CMP_INT_MODE0);
	/*
	(7)设置Timer中断优先级
	*/	
	IRQ_SET_PRIORITY(IRQ_TMR2,IRQ_PRIORITY_LOW);

	TMR2_AllIntEnable();
	IRQ_ALL_ENABLE();
	
	/*
	(8)设置IO复用
	*/	
	GPIO_SET_MUX_MODE(P16CFG, GPIO_P16_MUX_CC0);
	GPIO_SET_MUX_MODE(P17CFG, GPIO_P17_MUX_CC1);
	GPIO_SET_MUX_MODE(P02CFG, GPIO_P02_MUX_CC2);			
	GPIO_SET_MUX_MODE(P55CFG, GPIO_P55_MUX_CC3);

	/*
	(9)开启Timer
	*/
	TMR2_Start(TMR2_RUN_SYSCLK);
}
























