/*******************************************************************************
* Copyright (C) 2019 China Micro Semiconductor Limited Company. All Rights Reserved.
*
* This software is owned and published by:
* CMS LLC, No 2609-10, Taurus Plaza, TaoyuanRoad, NanshanDistrict, Shenzhen, China.
*
* BY DOWNLOADING, INSTALLING OR USING THIS SOFTWARE, YOU AGREE TO BE BOUND
* BY ALL THE TERMS AND CONDITIONS OF THIS AGREEMENT.
*
* This software contains source code for use with CMS
* components. This software is licensed by CMS to be adapted only
* for use in systems utilizing CMS components. CMS shall not be
* responsible for misuse or illegal use of this software for devices not
* supported herein. CMS is providing this software "AS IS" and will
* not be responsible for issues arising from incorrect user implementation
* of the software.
*
* This software may be replicated in part or whole for the licensed use,
* with the restriction that this Disclaimer and Copyright notice must be
* included with each copy of this software, whether used in part or whole,
* at all times.
*/

/*****************************************************************************/
/** \file system.h
**
** 
**
** History:
** 
*****************************************************************************/
#ifndef __SYSTEM_H__
#define __SYSTEM_H__
/*****************************************************************************/
/* Include files */
/*****************************************************************************/
#include "cms80f262xx.h"
/*****************************************************************************/
/* Global pre-processor symbols/macros ('#define') */
/*****************************************************************************/
/*----------------------------------------------------------------------------
 **System 系统时钟常用分频系数
---------------------------------------------------------------------------*/
#define		SYS_CLK_DIV_1 		(0x00)		
#define 	SYS_CLK_DIV_2		(0x01)
#define		SYS_CLK_DIV_4 		(0x02)
#define 	SYS_CLK_DIV_6		(0x03)
#define		SYS_CLK_DIV_8 		(0x04)
#define 	SYS_CLK_DIV_10		(0x05)
#define		SYS_CLK_DIV_12 		(0x06)
#define 	SYS_CLK_DIV_14		(0x07)
#define		SYS_CLK_DIV_16 		(0x08)
#define 	SYS_CLK_DIV_18		(0x09)
#define 	SYS_CLK_DIV_20		(0x0a)

/*----------------------------------------------------------------------------
 **System 系统LVD电压监测点
---------------------------------------------------------------------------*/
#define 	SYS_LVD_2_0V		(0x00)							/*LVD电压监测点2.0V*/
#define 	SYS_LVD_2_16V		(0x01<<LVD_LVDCON_LVDSEL_Pos)	/*LVD电压监测点2.16V*/
#define 	SYS_LVD_2_31V		(0x02<<LVD_LVDCON_LVDSEL_Pos)	/*LVD电压监测点2.31V*/
#define 	SYS_LVD_2_45V		(0x03<<LVD_LVDCON_LVDSEL_Pos)	/*LVD电压监测点2.45V*/
#define 	SYS_LVD_2_6V		(0x04<<LVD_LVDCON_LVDSEL_Pos)	/*LVD电压监测点2.6V*/
#define 	SYS_LVD_2_73V		(0x05<<LVD_LVDCON_LVDSEL_Pos)	/*LVD电压监测点2.73V*/
#define 	SYS_LVD_2_88V		(0x06<<LVD_LVDCON_LVDSEL_Pos)	/*LVD电压监测点2.88V*/
#define 	SYS_LVD_2_98V		(0x07<<LVD_LVDCON_LVDSEL_Pos)	/*LVD电压监测点2.98V*/

#define 	SYS_LVD_3_21V		(0x08<<LVD_LVDCON_LVDSEL_Pos)	/*LVD电压监测点3.21V*/
#define 	SYS_LVD_3_42V		(0x09<<LVD_LVDCON_LVDSEL_Pos)	/*LVD电压监测点3.42V*/
#define 	SYS_LVD_3_62V		(0x0a<<LVD_LVDCON_LVDSEL_Pos)	/*LVD电压监测点3.62V*/
#define 	SYS_LVD_3_81V		(0x0b<<LVD_LVDCON_LVDSEL_Pos)	/*LVD电压监测点3.81V*/

#define 	SYS_LVD_4_0V		(0x0c<<LVD_LVDCON_LVDSEL_Pos)	/*LVD电压监测点4.0V*/
#define 	SYS_LVD_4_2V		(0x0d<<LVD_LVDCON_LVDSEL_Pos)	/*LVD电压监测点4.2V*/
#define 	SYS_LVD_4_43V		(0x0e<<LVD_LVDCON_LVDSEL_Pos)	/*LVD电压监测点4.43V*/
#define 	SYS_LVD_4_6V		(0x0f<<LVD_LVDCON_LVDSEL_Pos)	/*LVD电压监测点4.6V*/


/*----------------------------------------------------------------------------
 **System 系统LVD电压监测模式
---------------------------------------------------------------------------*/
#define 	SYS_LVD_FALLING		(0x01)		
#define 	SYS_LVD_RISING		(0x02)
#define 	SYS_LVD_BOTH_EDGE	(0x03)

/*****************************************************************************/
/* Global type definitions ('typedef') */
/*****************************************************************************/


/*****************************************************************************/
/* Global variable declarations ('extern', definition in C source) */
/*****************************************************************************/


/*****************************************************************************/
/* Global function prototypes ('extern', definition in C source) */
/*****************************************************************************/
																						
/*****************************************************************************
 ** \brief	 SYS_EnableLVD
 **			 开启电压监测功能
 ** \param [in] none
 ** \return  none
 ** \note	 
*****************************************************************************/
void SYS_EnableLVD(void);
/*****************************************************************************
 ** \brief	 SYS_DisableLVD
 **			  关闭电压监测功能
 ** \param [in] none
 ** \return  none
 ** \note	 
*****************************************************************************/
void SYS_DisableLVD(void);
/*****************************************************************************
 ** \brief	 SYS_ConfigLVD
 **			 配置系统电压监测电压
 ** \param [in] LVDValue :(1)SYS_LVD_2_0V		LVD电压监测点2.0V					
						(2)	SYS_LVD_2_16V		LVD电压监测点2.16V
						(3)	SYS_LVD_2_31V		LVD电压监测点2.31V
						(4)	SYS_LVD_2_45V		LVD电压监测点2.45V
						(5)	SYS_LVD_2_6V		LVD电压监测点2.6V						
						(6)	SYS_LVD_2_73V		LVD电压监测点2.73V							
						(7)	SYS_LVD_2_88V		LVD电压监测点2.88V							
						(8)	SYS_LVD_2_98V		LVD电压监测点2.98V							
						(9)	SYS_LVD_3_21V		LVD电压监测点3.21V							
						(10)SYS_LVD_3_42V		LVD电压监测点3.42V							
						(11)SYS_LVD_3_62V		LVD电压监测点3.62V							
						(12)SYS_LVD_3_81V		LVD电压监测点3.81V							
						(13)SYS_LVD_4_0V		LVD电压监测点4.0V							
						(14)SYS_LVD_4_2V		LVD电压监测点4.2V						
						(15)SYS_LVD_4_43V		LVD电压监测点4.43V							
						(16)SYS_LVD_4_6V		LVD电压监测点4.6V							
 ** \return  none
 ** \note	 
*****************************************************************************/
void SYS_ConfigLVD(uint8_t LVDValue);

/*****************************************************************************
 ** \brief	 SYS_GetLVDFlag
 **			 获取LVD标志位
 ** \param [in] none
 ** \return  0:无触发 1：有触发
 ** \note	 
*****************************************************************************/
uint8_t SYS_GetLVDFlag(void);

/*****************************************************************************
 ** \brief	 SYS_ClearLVDFlag
 **			 清除LVD标志位
 ** \param [in] none
 ** \return  none
 ** \note	 
*****************************************************************************/
void SYS_ClearLVDFlag(void);

/*****************************************************************************
 ** \brief	 SYS_ConfigLVDDetectMode
 **			 配置电压监测功能
 ** \param [in] mode    (1)SYS_LVD_RISING
 **						(2)SYS_LVD_FALLING
 **						(3)SYS_LVD_BOTH_EDGE
 ** \return  none
 ** \note	 
*****************************************************************************/
void SYS_ConfigLVDDetectMode(uint8_t mode);
/*****************************************************************************
 ** \brief	 SYS_GetLVDOUTFlag
 **			 获取电源电压监测位
 ** \param [in] none
 ** \return  0:电源电压高于监测电压 1：电源电压低于监测电压
 ** \note	 
*****************************************************************************/
uint8_t SYS_GetLVDOUTFlag(void);

/*****************************************************************************
 ** \brief	 SYS_EnableSoftwareReset
 **			 使能软件复位System
 ** \param [in] none
 ** \return none
 ** \note
 *****************************************************************************/
void SYS_EnableSoftwareReset(void);
/*****************************************************************************
 ** \brief	 SYS_DisableSoftwareReset
 **			 关闭软件复位System
 ** \param [in] none
 ** \return none
 ** \note
 *****************************************************************************/
void SYS_DisableSoftwareReset(void);

/*****************************************************************************
 ** \brief	 SYS_GetWDTResetFlag
 **			 获取WDT复位System的标志
 ** \param [in] none
 ** \return 0：复位不由WDT溢出引起    1：复位由WDT溢出引起
 ** \note
 *****************************************************************************/
uint8_t SYS_GetWDTResetFlag(void);

/*****************************************************************************
 ** \brief	 SYS_GetPowerOnResetFlag
 **			 获取上电复位System的标志
 ** \param [in] none
 ** \return   0：复位不由上电复位引起    1：复位由上电复位引起
 ** \note
 *****************************************************************************/
uint8_t SYS_GetPowerOnResetFlag(void);

/*****************************************************************************
 ** \brief	 SYS_GetWWDTResetFlag
 **			 获取WWDT溢出复位System的标志
 ** \param [in] none
 ** \return   0：复位不由WWDT溢出复位引起    1：复位由WWDT溢出复位引起
 ** \note
 *****************************************************************************/
uint8_t SYS_GetWWDTResetFlag(void);

/*****************************************************************************
 ** \brief	 SYS_EnableWakeUp
 **			 使能休眠唤醒
 ** \param [in] none
 ** \return none
 ** \note	 可由外部中断唤醒
 *****************************************************************************/
void SYS_EnableWakeUp(void);
/*****************************************************************************
 ** \brief	 SYS_EnableWakeUp
 **			 关闭休眠唤醒
 ** \param [in] none
 ** \return none
 ** \note	
 *****************************************************************************/
void SYS_DisableWakeUp(void);

/*****************************************************************************
 ** \brief	 SYS_EnterStop
 **			 进入休眠中STOP状态
 ** \param [in] none
 ** \return none
 ** \note	
 *****************************************************************************/
void SYS_EnterStop(void);
/*****************************************************************************
 ** \brief	 SYS_EnterIdle
 **			 进入休眠模式中Idle状态
 ** \param [in] none
 ** \return none
 ** \note   
 *****************************************************************************/
void SYS_EnterIdle(void);


/*****************************************************************************
 ** \brief	 SYS_EnableSCM
 **			 使能停振监测功能
 ** \param [in] none
 ** \return none
 ** \note   
 *****************************************************************************/
void SYS_EnableSCM(void);
/*****************************************************************************
 ** \brief	 SYS_DisableSCM
 **			 关闭停振监测功能
 ** \param [in] none
 ** \return none
 ** \note   
 *****************************************************************************/
void SYS_DisableSCM(void);

/*****************************************************************************
 ** \brief	 SYS_EnableSCMInt
 **			 使能停振监测中断功能
 ** \param [in] none
 ** \return none
 ** \note   
 *****************************************************************************/
void SYS_EnableSCMInt(void);
/*****************************************************************************
 ** \brief	 SYS_DisableSCMInt
 **			 关闭停振监测中断功能
 ** \param [in] none
 ** \return none
 ** \note   
 *****************************************************************************/
void SYS_DisableSCMInt(void);
/*****************************************************************************
 ** \brief	 SYS_GetSCMIntFlag
 **			 获取停振监测中断标志位
 ** \param [in] none
 ** \return  0:无中断 1：有中断
 ** \note	 
*****************************************************************************/
uint8_t SYS_GetSCMIntFlag(void);
/*****************************************************************************
 ** \brief	 SYS_GetSCMState
 **			 获取停振监测状态位位
 ** \param [in] none
 ** \return  0:停振恢复 1：停振
 ** \note	 
*****************************************************************************/
uint8_t SYS_GetSCMState(void);
/*****************************************************************************
 ** \brief	 SYS_ClearSCMIntFlag
 **			 清除停振监测中断标志位
 ** \param [in] none
 ** \return  none
 ** \note	 
*****************************************************************************/
void SYS_ClearSCMIntFlag(void);

#endif /* __SYSTEM_H__ */



