/*******************************************************************************
* Copyright (C) 2019 China Micro Semiconductor Limited Company. All Rights Reserved.
*
* This software is owned and published by:
* CMS LLC, No 2609-10, Taurus Plaza, TaoyuanRoad, NanshanDistrict, Shenzhen, China.
*
* BY DOWNLOADING, INSTALLING OR USING THIS SOFTWARE, YOU AGREE TO BE BOUND
* BY ALL THE TERMS AND CONDITIONS OF THIS AGREEMENT.
*
* This software contains source code for use with CMS
* components. This software is licensed by CMS to be adapted only
* for use in systems utilizing CMS components. CMS shall not be
* responsible for misuse or illegal use of this software for devices not
* supported herein. CMS is providing this software "AS IS" and will
* not be responsible for issues arising from incorrect user implementation
* of the software.
*
* This software may be replicated in part or whole for the licensed use,
* with the restriction that this Disclaimer and Copyright notice must be
* included with each copy of this software, whether used in part or whole,
* at all times.
*/

/****************************************************************************/
/** \file uart.c
**
**  
**
**	History:
**	
*****************************************************************************/
/****************************************************************************/
/*	include files
*****************************************************************************/
#include "uart.h"
/****************************************************************************/
/*	Local pre-processor symbols/macros('#define')
****************************************************************************/

/****************************************************************************/
/*	Global variable definitions(declared in header file with 'extern')
****************************************************************************/

/****************************************************************************/
/*	Local type definitions('typedef')
****************************************************************************/

/****************************************************************************/
/*	Local variable  definitions('static')
****************************************************************************/

/****************************************************************************/
/*	Local function prototypes('static')
****************************************************************************/
/******************************************************************************
 ** \brief UART_ConfigRunMode
 **			UARTģʽ
 ** \param [in]     UARTn: 			(1)UART0
 **									(2)UART1
 **									(3)UART2
 **									(4)UART3 
 **					UARTMode:		(1)UART_MOD_SYN : ͬģʽ
 **									(2)UART_MOD_ASY_8BIT: 8λ첽ģʽ
 **									(3)UART_MOD_ASY_9BIT9λ첽ģʽ
 **									(4)UART_MOD_ASY_9BIT_STATIC9λʹ̶첽ģʽ
 **					UARTBaudTimer:  (1)UART_BAUD_TMR1 :	Timer1
 **									(2)UART_BAUD_TMR4 :	Timer4
 **									(3)UART_BAUD_TMR2 : Timer2
 **									(4)UART_BAUD_BRT : BRT
 **									(5)UART_BAUD_BRT1 : BRT1 
 ** \return none
******************************************************************************/
void UART_ConfigRunMode(uint8_t UARTn, uint8_t UARTMode, uint8_t UARTBaudTimer)
{	
	if(UARTn == UART0)
	{
		SCON0 &= ~(UART_SCON0_U0SMn_Msk);
		SCON0 |= (UARTMode<< UART_SCON0_U0SMn_Pos);
		FUNCCR &= ~(SYS_FUNCCR_UART0_CKS_Msk);
		FUNCCR |= UARTBaudTimer;
	}
	if(UARTn == UART1)
	{
		SCON1 &= ~(UART_SCON1_U1SMn_Msk);
		SCON1 |= (UARTMode<< UART_SCON1_U1SMn_Pos);		
		FUNCCR &= ~(SYS_FUNCCR_UART1_CKS_Msk);		
		FUNCCR |= UARTBaudTimer <<SYS_FUNCCR_UART1_CKS_Pos;					
	}	
	if(UARTn == UART2)
	{
		SFRS = 0x1;		/*ѡBANK1*/
		SCON2 &= ~(UART_SCON2_U2SMn_Msk);
		SCON2 |= (UARTMode<< UART_SCON2_U2SMn_Pos);
		FUNCCR1 &= ~(SYS_FUNCCR1_UART2_CKS_Msk);
		FUNCCR1 |= UARTBaudTimer;
		SFRS = 0x0;		/*ѡBANK0*/		
	}
	if(UARTn == UART3)
	{
		SFRS = 0x1;		/*ѡBANK1*/
		SCON3 &= ~(UART_SCON3_U3SMn_Msk);
		SCON3 |= (UARTMode<< UART_SCON3_U3SMn_Pos);		
		FUNCCR1 &= ~(SYS_FUNCCR1_UART3_CKS_Msk);		
		FUNCCR1 |= UARTBaudTimer <<SYS_FUNCCR1_UART3_CKS_Pos;	
		SFRS = 0x0;		/*ѡBANK0*/			
	}		
}
/******************************************************************************
 ** \brief UART_EnableDoubleFrequency
 **			ʹUARTʱƵģʽ
 ** \param [in]    UARTn: (1) UART0
 **						  (2) UART1
 **						  (3) UART2
 **						  (4) UART3 
 ** \return none
******************************************************************************/
void UART_EnableDoubleFrequency(uint8_t UARTn)
{
	if(UARTn == UART0)
	{
		PCON |= SYS_PCON_SMOD0_Msk;
	}
	if(UARTn == UART1)
	{
		PCON |= SYS_PCON_SMOD1_Msk;
	}

	if(UARTn == UART2)
	{
		SFRS = 0x1;		/*ѡBANK1*/
		PCON1 |= SYS_PCON1_SMOD2_Msk;
		SFRS = 0x0;		/*ѡBANK0*/		
	}
	if(UARTn == UART3)
	{
		SFRS = 0x1;		/*ѡBANK1*/
		PCON1 |= SYS_PCON1_SMOD3_Msk;
		SFRS = 0x0;		/*ѡBANK0*/
	}	
}
/******************************************************************************
 ** \brief UART_DisableDoubleFrequency
 **			رUARTʱƵģʽ
 ** \param [in]    UARTn: (1) UART0
 **						  (2) UART1
 **						  (3) UART2
 **						  (4) UART3 
 ** \return none
******************************************************************************/
void UART_DisableDoubleFrequency(uint8_t UARTn)
{
	if(UARTn == UART0)
	{
		PCON &= ~(SYS_PCON_SMOD0_Msk);
	}
	if(UARTn == UART1)
	{
		PCON &= ~(SYS_PCON_SMOD1_Msk);
	}
	if(UARTn == UART2)
	{
		SFRS = 0x1;		/*ѡBANK1*/
		PCON1 &= ~(SYS_PCON1_SMOD2_Msk);
		SFRS = 0x0;		/*ѡBANK0*/		
	}
	if(UARTn == UART3)
	{
		SFRS = 0x1;		/*ѡBANK1*/
		PCON1 &= ~(SYS_PCON1_SMOD3_Msk);
		SFRS = 0x0;		/*ѡBANK0*/
	}			
}



/******************************************************************************
 ** \brief UART_EnableReceive
 **			ģʽ
 ** \param [in]    UARTn: (1) UART0
 **						  (2) UART1
 **						  (3) UART2
 **						  (4) UART3 
 ** \return 
******************************************************************************/
void UART_EnableReceive(uint8_t UARTn)
{
	if(UARTn == UART0)
	{
		SCON0 |= UART_SCON0_U0REN_Msk;
	}
	if(UARTn == UART1)
	{
		SCON1 |= UART_SCON1_U1REN_Msk;
	}
	
	if(UARTn == UART2)
	{
		SFRS = 0x1;		/*ѡBANK1*/			
		SCON2 |= UART_SCON2_U2REN_Msk;
		SFRS = 0x0;		/*ѡBANK0*/			
	}
	if(UARTn == UART3)
	{
		SFRS = 0x1;		/*ѡBANK1*/	
		SCON3 |= UART_SCON3_U3REN_Msk;
		SFRS = 0x0;		/*ѡBANK0*/					
	}	
	
}
/******************************************************************************
 ** \brief UART_DisableReceive
 **			رսģʽ
 ** \param [in]    UARTn: (1) UART0
 **						  (2) UART1
 **						  (3) UART2
 **						  (4) UART3 
 ** \return 
******************************************************************************/
void UART_DisableReceive(uint8_t UARTn)
{
	if(UARTn == UART0)
	{
		SCON0 &= ~(UART_SCON0_U0REN_Msk);
	}
	if(UARTn == UART1)
	{
		SCON1 &= ~(UART_SCON1_U1REN_Msk);
	}
	
	if(UARTn == UART2)
	{
		SFRS = 0x1;		/*ѡBANK1*/			
		SCON2 &= ~(UART_SCON2_U2REN_Msk);
		SFRS = 0x0;		/*ѡBANK0*/			
	}
	if(UARTn == UART3)
	{
		SFRS = 0x1;		/*ѡBANK1*/	
		SCON3 &= ~(UART_SCON3_U3REN_Msk);
		SFRS = 0x0;		/*ѡBANK0*/					
	}			
}

/******************************************************************************
 ** \brief UART_EnableInt
 **			ж
 ** \param [in]    UARTn: (1) UART0
 **						  (2) UART1
 **						  (3) UART2
 **						  (4) UART3 
 ** \return 
******************************************************************************/
void UART_EnableInt(uint8_t UARTn)
{
	if(UARTn == UART0)
	{
		ES0 =1;
	}
	if(UARTn == UART1)
	{
		ES1 =1;
	}

	if(UARTn == UART2)
	{
		EIE3 |= IRQ_EIE3_ES2_Msk;
	}
	if(UARTn == UART3)
	{
		EIE3 |= IRQ_EIE3_ES3_Msk;
	}	
}
/******************************************************************************
 ** \brief UART_DisableInt
 **			رж
 ** \param [in]    UARTn: (1) UART0
 **						  (2) UART1
 **						  (3) UART2
 **						  (4) UART3 
 ** \return 
******************************************************************************/
void UART_DisableInt(uint8_t UARTn)
{
	if(UARTn == UART0)
	{
		ES0 =0;
	}
	if(UARTn == UART1)
	{
		ES1 =0;
	}
	if(UARTn == UART2)
	{
		EIE3 &= ~(IRQ_EIE3_ES2_Msk);
	}
	if(UARTn == UART3)
	{
		EIE3 &= ~(IRQ_EIE3_ES3_Msk);
	}
}
/******************************************************************************
 ** \brief UART_GetReceiveIntFlag
 **			ȡжϱ־λ
 ** \param [in]    UARTn: (1) UART0
 **						  (2) UART1
 **						  (3) UART2
 **						  (4) UART3 
 ** \return 0жϣ1ж
******************************************************************************/
uint8_t  UART_GetReceiveIntFlag(uint8_t UARTn)
{
	uint8_t uartFlag;
	uartFlag =0;
	if(UART0 ==  UARTn)
	{
		uartFlag =((SCON0 & UART_SCON0_RI0_Msk)? 1:0);
	}
	if(UART1 == UARTn)
	{
		uartFlag =((SCON1 & UART_SCON1_RI1_Msk)? 1:0);
	}	
	if(UARTn == UART2)
	{
		SFRS = 0x1;		/*ѡBANK1*/			
		uartFlag = ((SCON2 & UART_SCON2_RI2_Msk)? 1:0);
		SFRS = 0x0;		/*ѡBANK0*/			
	}
	if(UARTn == UART3)
	{
		SFRS = 0x1;		/*ѡBANK1*/	
		uartFlag =((SCON3 & UART_SCON3_RI3_Msk)? 1:0);
		SFRS = 0x0;		/*ѡBANK0*/					
	}		
	
	return uartFlag ;
}

/******************************************************************************
 ** \brief UART_ClearReceiveIntFlag
 **			жϱ־λ
 ** \param [in]    UARTn: (1) UART0
 **						  (2) UART1
 **						  (3) UART2
 **						  (4) UART3 
 ** \return 
******************************************************************************/
void UART_ClearReceiveIntFlag(uint8_t UARTn)
{
	uint8_t temp;
	
	if(UART0 ==  UARTn)
	{
		temp  = SCON0;
		temp &= ~(UART_SCON0_RI0_Msk);
		SCON0 = temp| UART_SCON0_TI0_Msk;
	}
	if(UART1 == UARTn)
	{
		temp  = SCON1;
		temp &= ~(UART_SCON1_RI1_Msk);
		SCON1 = temp | UART_SCON1_TI1_Msk;		
	}	
	
	if(UARTn == UART2)
	{
		SFRS = 0x1;		/*ѡBANK1*/	
		temp  = SCON2;
		temp &= ~(UART_SCON2_RI2_Msk);
		SCON2 = temp | UART_SCON2_TI2_Msk;				
		SFRS = 0x0;		/*ѡBANK0*/			
	}
	if(UARTn == UART3)
	{
		SFRS = 0x1;		/*ѡBANK1*/
		temp  = SCON3;
		temp &= ~(UART_SCON3_RI3_Msk);
		SCON3 = temp | UART_SCON3_TI3_Msk;					
		SFRS = 0x0;		/*ѡBANK0*/					
	}			
}

/******************************************************************************
 ** \brief UART_GetSendIntFlag
 **			ȡжϱ־λ
 ** \param [in]    UARTn: (1) UART0
 **						  (2) UART1
 **						  (3) UART2
 **						  (4) UART3 
 ** \return 0жϣ1ж
******************************************************************************/
uint8_t  UART_GetSendIntFlag(uint8_t UARTn)
{
	uint8_t uartFlag;
	uartFlag =0;
	if(UART0 ==  UARTn)
	{
		return((SCON0 & UART_SCON0_TI0_Msk)? 1:0);
	}
	if(UART1 ==  UARTn)
	{
		return((SCON1 & UART_SCON1_TI1_Msk)? 1:0);
	}
	if(UARTn == UART2)
	{
		SFRS = 0x1;		/*ѡBANK1*/			
		uartFlag = ((SCON2 & UART_SCON2_TI2_Msk)? 1:0);
		SFRS = 0x0;		/*ѡBANK0*/			
	}
	if(UARTn == UART3)
	{
		SFRS = 0x1;		/*ѡBANK1*/	
		uartFlag =((SCON3 & UART_SCON3_TI3_Msk)? 1:0);
		SFRS = 0x0;		/*ѡBANK0*/					
	}			
	return uartFlag;
}

/******************************************************************************
 ** \brief UART_ClearSendIntFlag
 **			жϱ־λ
 ** \param [in]    UARTn: (1) UART0
 **						  (2) UART1
 **						  (3) UART2
 **						  (4) UART3 
 ** \return 
******************************************************************************/
void UART_ClearSendIntFlag(uint8_t UARTn)
{
	uint8_t temp;
	
	if(UART0 ==  UARTn)
	{
		temp  = SCON0;
		temp &= ~(UART_SCON0_TI0_Msk);
		SCON0 = temp | UART_SCON0_RI0_Msk;		
	}
	if(UART1 == UARTn)
	{
		temp  = SCON1;
		temp &= ~(UART_SCON1_TI1_Msk);
		SCON1 = temp | UART_SCON1_RI1_Msk;		
	}	
	if(UARTn == UART2)
	{
		SFRS = 0x1;		/*ѡBANK1*/	
		temp  = SCON2;
		temp &= ~(UART_SCON2_TI2_Msk);
		SCON2 = temp | UART_SCON2_RI2_Msk;		
		SFRS = 0x0;		/*ѡBANK0*/			
	}
	if(UARTn == UART3)
	{
		SFRS = 0x1;		/*ѡBANK1*/
		
		temp  = SCON3;
		temp &= ~(UART_SCON3_TI3_Msk);
		SCON3 = temp | UART_SCON3_RI3_Msk;				
		SFRS = 0x0;		/*ѡBANK0*/					
	}			
}

/******************************************************************************
 ** \brief UART_GetBuff
 **			ȡBuffֵ
 ** \param [in]    UARTn: (1) UART0
 **						  (2) UART1
 **						  (3) UART2
 **						  (4) UART3 
 ** \return 
******************************************************************************/
uint8_t UART_GetBuff(uint8_t UARTn)
{
	uint8_t  uartbuf;
	uartbuf =0;
	if(UART0 == UARTn)
	{
		uartbuf = SBUF;
	}
	if(UART1 ==  UARTn)
	{
		uartbuf = SBUF1;
	}
	if(UARTn == UART2)
	{
		SFRS = 0x1;		/*ѡBANK1*/		
		uartbuf = SBUF2;	
		SFRS = 0x0;		/*ѡBANK0*/			
	}
	if(UARTn == UART3)
	{
		SFRS = 0x1;		/*ѡBANK1*/
		uartbuf = SBUF3;		
		SFRS = 0x0;		/*ѡBANK0*/					
	}			
	return uartbuf;
}

/******************************************************************************
 ** \brief UART_SendBuff
 **			ݵBuff
 ** \param [in]    UARTn: (1) UART0
 **						  (2) UART1
 **						  (3) UART2
 **						  (4) UART3 
 **				   UARTSendValue : ͵8λֵ
 ** \return 
******************************************************************************/
void UART_SendBuff(uint8_t UARTn, uint8_t UARTSendValue)
{
	if(UART0 == UARTn)
	{
		SBUF = UARTSendValue;
	}
	if(UART1 == UARTn)
	{
		SBUF1 = UARTSendValue;
	}
	
	if(UARTn == UART2)
	{
		SFRS = 0x1;		/*ѡBANK1*/		
		SBUF2 = UARTSendValue;	
		SFRS = 0x0;		/*ѡBANK0*/			
	}
	if(UARTn == UART3)
	{
		SFRS = 0x1;		/*ѡBANK1*/
		SBUF3 = UARTSendValue;		
		SFRS = 0x0;		/*ѡBANK0*/					
	}			
}

/******************************************************************************
 ** \brief UART_SendNinthBit
 **			ݵĵھλ
 ** \param [in]    UARTn: (1) UART0
 **						  (2) UART1
 **						  (3) UART2
 **						  (4) UART3 
 **				   UARTSendValue : ͵ĵھλֵ
 ** \return 
******************************************************************************/
void UART_SendNinthBit(uint8_t UARTn, uint8_t UARTSendValue)
{
	if(UART0 == UARTn)
	{
		if(0 == UARTSendValue)
		{
			SCON0 &= ~(UART_SCON0_U0TB8_Msk);
		}
		else
		{
			SCON0 |= UART_SCON0_U0TB8_Msk;	
		}
	}
	if(UART1 == UARTn)
	{
		if(0 == UARTSendValue)
		{
			SCON1 &= ~(UART_SCON1_U1TB8_Msk);
		}
		else 
		{
			SCON1 |= UART_SCON1_U1TB8_Msk;	
		}
	}	
	if(UARTn == UART2)
	{
		SFRS = 0x1;		/*ѡBANK1*/		
		if(0 == UARTSendValue)
		{
			SCON2 &= ~(UART_SCON2_U2TB8_Msk);
		}
		else 
		{
			SCON2 |= UART_SCON2_U2TB8_Msk;	
		}		
		SFRS = 0x0;		/*ѡBANK0*/			
	}
	if(UARTn == UART3)
	{
		SFRS = 0x1;		/*ѡBANK1*/		
		if(0 == UARTSendValue)
		{
			SCON3 &= ~(UART_SCON3_U3TB8_Msk);
		}
		else 
		{
			SCON3 |= UART_SCON3_U3TB8_Msk;	
		}		
		SFRS = 0x0;		/*ѡBANK0*/						
	}		
	
}
/******************************************************************************
 ** \brief UART_GetNinthBit
 **			ȡݵĵھλ
 ** \param [in]    UARTn: (1) UART0
 **						  (2) UART1
 **						  (3) UART2
 **						  (4) UART3 
 ** \return 0/1
******************************************************************************/
uint8_t UART_GetNinthBit(uint8_t UARTn)
{
	uint8_t ninthbit;
	ninthbit=0;
	if(UARTn == UART0)
	{
		ninthbit= ((SCON0 & UART_SCON0_U0RB8_Msk)? 1:0);
	}
	if(UARTn == UART1)
	{
		ninthbit= ((SCON1 & UART_SCON1_U1RB8_Msk)? 1:0);
	}
	if(UARTn == UART2)
	{
		SFRS = 0x1;		/*ѡBANK1*/		
		ninthbit= ((SCON2 & UART_SCON2_U2RB8_Msk)? 1:0);		
		SFRS = 0x0;		/*ѡBANK0*/			
	}
	if(UARTn == UART3)
	{
		SFRS = 0x1;		/*ѡBANK1*/
		ninthbit= ((SCON3 & UART_SCON3_U3RB8_Msk)? 1:0);	
		SFRS = 0x0;		/*ѡBANK0*/					
	}
	return ninthbit;
}
/******************************************************************************
 ** \brief UART_EnableBRT
 **		   ʹBRTʱģ
 ** \param [in]brtn : BRT BRT1
 ** \return none
******************************************************************************/
void UART_EnableBRT(uint8_t brtn)
{
	if(BRT == brtn)
	{
		BRTCON |= UART_BRTCON_BRTEN_Msk;	
	}
	if(BRT1 == brtn)
	{
		BRT1CON |= UART_BRT1CON_BRT1EN_Msk;	
	}	
}
/******************************************************************************
 ** \brief UART_ConfigBRTClk
 **		   BRTģʱ
 ** \param [in]brtn : BRT BRT1
 **			   BRTClkDiv : BRT_CLK_DIV_1 ~ BRT_CLK_DIV_128
 ** \return none
******************************************************************************/
void UART_ConfigBRTClk(uint8_t brtn, uint8_t BRTClkDiv)
{
	if(BRT == brtn)
	{
		BRTCON &= ~(UART_BRTCON_BRTCKDIV_Msk);	
		BRTCON |= BRTClkDiv;	
	}
	if(BRT1 == brtn)
	{
		BRT1CON &= ~(UART_BRT1CON_BRT1CKDIV_Msk);	
		BRT1CON |= BRTClkDiv;
	}			
}

/******************************************************************************
 ** \brief UART_ConfigBRTPeriod
 **		   BRTģʱ
 ** \param [in]brtn : BRT BRT1
 **        BRTPeriod: 16bit
 ** \return none
******************************************************************************/
void UART_ConfigBRTPeriod(uint8_t brtn, uint16_t BRTPeriod)
{	
	if(BRT == brtn)
	{
		BRTDL = BRTPeriod;
		BRTDH = BRTPeriod>>8;
	}
	if(BRT1 == brtn)
	{
		BRT1DL = BRTPeriod;
		BRT1DH = BRTPeriod>>8;
	}		
}
/******************************************************************************
 ** \brief UART_DisableBRT
 **		   رBRTʱģ
 ** \param [in]brtn : BRT BRT1
 ** \return none
******************************************************************************/
void UART_DisableBRT(uint8_t brtn)
{
	if(BRT == brtn)
	{
		BRTCON &= ~(UART_BRTCON_BRTEN_Msk);
	}
	if(BRT1 == brtn)
	{
		BRT1CON &= ~(UART_BRT1CON_BRT1EN_Msk);	
	}	
}







